<?php

namespace Drupal\cache_review\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Security\TrustedCallbackInterface;

/**
 * Provides a test block with Lazy Builder.
 *
 * @Block(
 *   id = "cache_review_block_lazy",
 *   admin_label = @Translation("Test block with Lazy Builder"),
 *   category = @Translation("cache_review")
 * )
 */
class BlockLazy extends BlockBase implements TrustedCallbackInterface {

  /**
   * {@inheritdoc}
   */
  public function build() {
    $output = [
      '#lazy_builder' => [static::class . '::lazyBuilderBlock', []],
      // We can force create placeholders by
      // '#create_placeholder' => TRUE.
      // Or use one of the options as set in auto_placeholdering_conditions.
      // '#create_placeholder' => TRUE.
      '#cache' => [
        'contexts' => ['user'],
      ],
    ];

    return $output;
  }

  /**
   * Lazy builder callback.
   */
  public static function lazyBuilderBlock() {
    $user_name = \Drupal::currentUser()->getDisplayName();
    $text = sprintf('<span class="date">%s </span><strong>Block from Lazy Builder</strong><br> Hello <i>%s</i>,
      Lorem ipsum dolor sit amet, consectetur adipiscing elit. Praesent nec ante auctor,
      feugiat sem nec,mollis mi. In id dapibus tortor.Vestibulum leo quam, facilisis non porttitor et,
      dapibus ut elit. Suspendisse non ligula malesuada, imperdiet ante sagittis, lobortis odio.',
      date('H:i:s'), $user_name);

    $output['#markup'] = sprintf('%s<br><strong><i>Cache options inside block lazy placeholder: %s</i></strong>', $text, json_encode(['contexts' => ['user']]));
    return $output;
  }

  /**
   * {@inheritdoc}
   */
  public static function trustedCallbacks() {
    $callbacks[] = 'lazyBuilderBlock';
    return $callbacks;
  }

}
