<?php

namespace Drupal\Tests\cache_review\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Tests for the cache_review module.
 *
 * @group cache_review
 */
class CacheReviewTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * Modules to enable.
   *
   * @var array
   */
  protected static $modules = ['cache_review'];

  /**
   * The installation profile to use with this test.
   *
   * @var string
   */
  protected $profile = 'minimal';

  /**
   * Test menu links and routes.
   */
  public function testCacheReviewMenu() {
    $session = $this->assertSession();

    $account = $this->drupalCreateUser(['access content']);
    $this->drupalLogin($account);

    $this->drupalGet('<front>');
    $session->elementExists('css', 'div.cache-designition');

    // Verify cache_review pages.
    $this->drupalGet('cache-review');
    $session->linkExists('Cached page with max-age for items');
    $session->linkExists('Uncacheable page, has lazy, some items cached due to keys');
    $session->linkExists('Cached page with lazy items');
    $this->drupalGet('cache-review/cached-max-age');
    $session->pageTextContains('Options:{"max-age":-1,"tags":["user:1"]}');
    $session->pageTextContains('Options:{"max-age":20}');
    $session->pageTextContains('Options:{"max-age":10,"keys":["demo_child"]}');
    $session->pageTextContains('Options:{"contexts":["url.query_args"]}');
    $this->drupalGet('cache-review/uncacheable-lazy-keys');
    $session->pageTextContains('Options:{"max-age":-1}');
    $session->pageTextContains('Options:{"contexts":["user","url.query_args"],"keys":["demo_contexts_url"]}');
    $session->pageTextContains('Options:{"contexts":["url.query_args:test"],"keys":["demo_contexts_url_test"]}');
    $session->pageTextContains('This item has context session and #lazy_builder options. As result - item is not cached.');
    $session->pageTextContains('This item has #lazy_builder and #create_placeholder options. Item is not cached.');
    $this->drupalGet('cache-review/cached-lazy');
    $session->assertEscaped('Block from Lazy Builder');
    $session->pageTextContains('Cache options inside block lazy placeholder: {"contexts":["user"]}');
    $session->pageTextContains('Options:{"max-age":["-1"],"keys":["keys_permanent_test"]}');
    $session->pageTextContains('Options: --');
    $session->pageTextContains('Options:{"contexts":["url.query_args"]}');
    $session->pageTextContains('Cache options inside lazy placeholder: {"contexts":["user"]}');
  }

}
